@@ -19,16 +19,17 @@ import time
 from OSRSBytes.Utilities import Utilities
 
 # META Data
-__copyright__  = 'Copyright 2022, CFDeadlines'
+__copyright__  = 'Copyright 2023, CFDeadlines'
 __credits__    = ['CFDeadlines (Lead Programmer, Creator)', 'Riley Fitzgibbons (Contributor)']
 __license__    = 'EPL-2.0 (https://github.com/Coffee-fueled-deadlines/OSRSBytes/blob/master/LICENSE)'
-__version__    = '1.3.0'
+__version__    = '1.3.1'
 __maintainer__ = {
         'CFDeadlines': 'cookm0803@gmail.com',
         'Riley Fitz': "rileyfitzgibbons@gmail.com"
     }
 __email__      = 'cookm0803@gmail.com'
 __status__     = 'Open'
+__test__ = "this is a test again"
 
 ################
 #  Exceptions  #
@@ -51,6 +52,9 @@ class LMSArenaError(Exception):
 class BossError(Exception):
     pass
 
+class BountyError(Exception):
+    pass
+
 ############################
 #  Do not run if __main__  #
 ############################
@@ -330,6 +334,7 @@ class Hiscores(object):
             "nightmare",
             "phosanis_nightmare",
             "obor",
+            "phantom_muspah",
             "sarachnis",
             "scorpia",
             "skotizo",
